# My Palace

One-sentence description of what this palace covers.

## Rooms

| Room | Description | Path |
|---|---|---|
| `toolchain` | Dev tools, languages, conventions | `global/toolchain/` |
| `my-project` | Architecture, gotchas, key files | `projects/my-project/` |

---
_Last consolidated: YYYY-MM-DD_

<!--
NAVIGATION: Read this file first. Identify the relevant room, then read only
that room's files. Do not load the full palace speculatively.
-->
